#!/bin/bash

PCONFIG=$LBPCONFIG/$PDIR/pvsolcast/solcast_config.json
SYSCONFIG=$LBSCONFIG/general.cfg
PLOG1=$LBPLOG/$PDIR/pvsolcast/solcast_1.log
PLOG2=$LBPLOG/$PDIR/pvsolcast/solcast_2.log
PLOG3=$LBPLOG/$PDIR/pvsolcast/solcast_3.log
PLOG4=$LBPLOG/$PDIR/pvsolcast/solcast_4.log
PLOG5=$LBPLOG/$PDIR/pvsolcast/solcast_5.log
PLOG_SUM=$LBPLOG/$PDIR/pvsolcast/solcast_sum.log
PLOG_SUM_MN=$LBPLOG/$PDIR/pvsolcast/solcast_sum_mn.log
DATA_DIR=$LBPDATA/$PDIR/pvsolcast/
active_1=$(jq '.system_1.active' $PCONFIG | tr -d '"')
active_2=$(jq '.system_2.active' $PCONFIG | tr -d '"') 
active_3=$(jq '.system_3.active' $PCONFIG | tr -d '"')
active_4=$(jq '.system_4.active' $PCONFIG | tr -d '"')
active_5=$(jq '.system_5.active' $PCONFIG | tr -d '"')
auto=$(jq '.auto' $PCONFIG | tr -d '"')
mn_ss=$(jq '.mn_ss' $PCONFIG | tr -d '"')
debug=$(jq '.debug' $PCONFIG | tr -d '"')
declare -a  request_time=$(jq '.timer' $PCONFIG | tr -d '"' | tr -d ',' | tr \[ \( | tr \] \)) 
request_time=("${request_time[@]}")
hour=$(date +"%k")
clock=$(date '+%Y-%m-%d %H:%M:%S')
reqe=0

if [ ! -d "$LBPLOG/$PDIR/pvsolcast/" ]; then
  mkdir $LBPLOG/$PDIR/pvsolcast/
fi

iniparser() {
    INI_FILE=$1
    INI_SECTION=$2
    eval `sed -e 's/[[:space:]]*\=[[:space:]]*/=/g' \
        -e 's/;.*$//' \
        -e 's/[[:space:]]*$//' \
        -e 's/^[[:space:]]*//' \
        -e "s/^\(.*\)=\([^\"']*\)$/$INI_SECTION\1=\"\2\"/" \
        < $INI_FILE \
        | sed -n -e "/^\[$INI_SECTION\]/,/^\s*\[/{/^[^;].*\=.*/p;}"`
}
 
iniparser $SYSCONFIG "WEBSERVER"
iniparser $SYSCONFIG "NETWORK"

# Berechnung Abruf Sonnenauf- / untergang
lat=$(jq '.system_1.lat' $PCONFIG | tr -d '"')
lon=$(jq '.system_1.lon' $PCONFIG | tr -d '"')
zoneinfo=$(date +%z)
T=`date +%j`
pi="3.14159265358979323844"
rad=$(echo "${pi}/180" | bc -l)
h=$(echo "-(5/6)*(${rad})" | bc -l)
BreiteRAD=$(echo "${lat}*${rad}" | bc -l)

sonnendekl=`echo "0.409526325277017*s(0.0169060504029192*(${T}-80.0856919827619))" | bc -l`
sonnendeklDEG=$(echo "${sonnendekl} / ${rad}" | bc -l)
arccosint=$(echo "(s(${h})-s(${BreiteRAD})*s(${sonnendekl}))/(c(${BreiteRAD})*c(${sonnendekl}))" | bc -l)
arccosintsign=${arccosint:0:1}
if [ ${arccosintsign} == "-" ]; then
  usesign="+"
else
  usesign="-"
fi
arc2cosint=$(echo "(${arccosint}) * (${arccosint})" | bc -l)
acoszeit=$(echo "${pi}/2 ${usesign} a(sqrt(${arc2cosint} / (1 - (${arc2cosint}) ) ) ) " | bc -l)
zeitdiff=$(echo "12*${acoszeit}/${pi}" | bc -l)
zeitgleich=$(echo "-0.170869921174742*s(0.0336997028793971 * ${T} + 0.465419984181394) - 0.129890681040717*s(0.0178674832556871*${T} - 0.167936777524864)" | bc -l)
aufgang=$(echo "12-(${zeitdiff})-(${zeitgleich})-(${lon}/15)${zoneinfo:0:3}" | bc -l)
untergang=$(echo "12+(${zeitdiff})-(${zeitgleich})-(${lon}/15)${zoneinfo:0:3}" | bc -l)
abruf_aufgang=$(echo $aufgang | xargs printf "%.0f\n")
abruf_untergang=$(echo $untergang  | awk '{printf "%.0f\n", $1}')
abruf_untergang=$(echo "scale=0; $abruf_untergang -1" | bc)
interval=$(echo "scale=1; ($abruf_untergang-$abruf_aufgang)/8" | bc | awk '{printf "%.0f\n", $1}')


if [ $mn_ss == 1 ]; then
firstcall=0
else
firstcall=$abruf_aufgang
fi

req_arr=( $firstcall $abruf_aufgang 12 $abruf_untergang)
cal_timer=$abruf_aufgang
for i in {1..7}
do
   cal_timer=$(echo "scale=0; $cal_timer + $interval" | bc)
   req_arr+=($cal_timer)
done
arr_sorted=()
while IFS= read -r item; do
  arr_sorted+=( "$item" )
done < <(printf '%s\n' "${req_arr[@]}" | sort -t _ -g)

if [ $auto == 1 ]; then
request_time=()
request_time=($(echo ${arr_sorted[@]} | tr [:space:] '\n' | awk '!a[$0]++'))
else 
request_time+=( $firstcall )
request_time=($(echo ${request_time[@]} | tr [:space:] '\n' | awk '!a[$0]++'))
fi
#echo ${request_time[@]}
#exit 0

for i in "${request_time[@]}"
do
	if [ $active_1 == 1 ]; then
		if [ $hour == $i ];then
		  if [ $debug == 1 ]; then 
			echo "$clock - Request by cron - System 1" >> $PLOG1
		  fi	  
		  /usr/bin/php $LBPHTML/pvsolcast/solcast.php 1 2>&1 >/dev/null
		  reqe=1
		fi
	else 
		file_rm=$DATA_DIR"/solcast_system_1.txt"
		if [ -f "$file_rm" ] ; then
			rm -rf "$file_rm"
		fi	
	fi
	if [ $active_2 == 1 ]; then
		if [ $hour == $i ];then
		  if [ $debug == 1 ]; then 
			echo "$clock - Request by cron - System 2" >> $PLOG2
		  fi
		  /usr/bin/php $LBPHTML/pvsolcast/solcast.php 2 2>&1 >/dev/null
		  reqe=1
		fi
	else 
		file_rm=$DATA_DIR"/solcast_system_2.txt"
		if [ -f "$file_rm" ] ; then
			rm -rf "$file_rm"
		fi	
	fi
	if [ $active_3 == 1 ]; then
		if [ $hour == $i ];then
		  if [ $debug == 1 ]; then 
			echo "$clock - Request by cron - System 3" >> $PLOG3
		  fi
		  /usr/bin/php $LBPHTML/pvsolcast/solcast.php 3 2>&1 >/dev/null
		  reqe=1
		fi
	else 
		file_rm=$DATA_DIR"/solcast_system_3.txt"
		if [ -f "$file_rm" ] ; then
			rm -rf "$file_rm"
		fi	
	fi	
	if [ $active_4 == 1 ]; then
		if [ $hour == $i ];then
		  if [ $debug == 1 ]; then 
			echo "$clock - Request by cron - System 4" >> $PLOG4
		  fi
		  /usr/bin/php $LBPHTML/pvsolcast/solcast.php 4 2>&1 >/dev/null
		  reqe=1
		fi
	else 
		file_rm=$DATA_DIR"/solcast_system_4.txt"
		if [ -f "$file_rm" ] ; then
			rm -rf "$file_rm"
		fi		
	fi
	if [ $active_5 == 1 ]; then
		if [ $hour == $i ];then
		  if [ $debug == 1 ]; then 
			echo "$clock - Request by cron - System 5" >> $PLOG5
		  fi
		  /usr/bin/php $LBPHTML/pvsolcast/solcast.php 5 2>&1 >/dev/null
		  reqe=1
		fi
	else
		file_rm=$DATA_DIR"/solcast_system_5.txt"
		if [ -f "$file_rm" ] ; then
			rm -rf "$file_rm"
		fi	
	fi	
done

if [ $hour == $firstcall ];then
	sleep 1
	if [ $debug == 1 ]; then 
		echo "$clock - Request by cron - summarize and save as first call" >> $PLOG_SUM_MN
	fi
	/usr/bin/php $LBPHTML/pvsolcast/solcast_sum_mn.php 2>&1 >/dev/null
fi

if [ $reqe -eq 1 ]; then
	sleep 1
	if [ $debug == 1 ]; then 
		echo "$clock - Request by cron - summarize" >> $PLOG_SUM
	fi	
	/usr/bin/php $LBPHTML/pvsolcast/solcast_sum.php 2>&1 >/dev/null
fi

if [ $debug == 1 ]; then
	if [ $reqe == 0 ]; then
		if [ $active_1 == 1 ]; then
			echo "$clock - Hourly-Cron, Hour not set for Request - System 1" >> $PLOG1
		fi
		if [ $active_2 == 1 ]; then
			echo "$clock - Hourly-Cron, Hour not set for Request - System 2" >> $PLOG2
		fi
		if [ $active_3 == 1 ]; then
			echo "$clock - Hourly-Cron, Hour not set for Request - System 3" >> $PLOG3
		fi
		if [ $active_4 == 1 ]; then
			echo "$clock - Hourly-Cron, Hour not set for Request - System 4" >> $PLOG4
		fi	
		if [ $active_5 == 1 ]; then
			echo "$clock - Hourly-Cron, Hour not set for Request - System 5" >> $PLOG5
		fi			
	fi
fi
